# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_ansible.models.patchedansible_ansible_repository import PatchedansibleAnsibleRepository

class TestPatchedansibleAnsibleRepository(unittest.TestCase):
    """PatchedansibleAnsibleRepository unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PatchedansibleAnsibleRepository:
        """Test PatchedansibleAnsibleRepository
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PatchedansibleAnsibleRepository`
        """
        model = PatchedansibleAnsibleRepository()
        if include_optional:
            return PatchedansibleAnsibleRepository(
                pulp_labels = {
                    'key' : ''
                    },
                name = '0',
                description = '0',
                retain_repo_versions = 56,
                remote = '',
                last_synced_metadata_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                gpgkey = '0',
                private = True
            )
        else:
            return PatchedansibleAnsibleRepository(
        )
        """

    def testPatchedansibleAnsibleRepository(self):
        """Test PatchedansibleAnsibleRepository"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
